from django.db import models
from django.utils.translation import ugettext_lazy as _


class Ostan(models.Model):
    name = models.CharField(_('Name'), max_length=255)
    amar_code = models.IntegerField(_('Amar Code'))

    def __str__(self):
        return self.name

    class Meta:
        verbose_name = _('Ostan')
        verbose_name_plural = _('Ostans')
        ordering = ('id',)


class Shahrestan(models.Model):
    ostan = models.ForeignKey(
        Ostan,
        verbose_name=_('Ostan'),
        related_name='shahrestans',
        on_delete=models.CASCADE
    )
    name = models.CharField(_('Name'), max_length=255)
    amar_code = models.IntegerField(_('Amar Code'))

    def __str__(self):
        return self.name

    class Meta:
        verbose_name = _('Shahrestan')
        verbose_name_plural = _('Shahrestans')
        ordering = ('id',)


class Bakhsh(models.Model):
    ostan = models.ForeignKey(
        Ostan,
        verbose_name=_('Ostan'),
        related_name='bakhshs',
        on_delete=models.CASCADE
    )
    shahrestan = models.ForeignKey(
        Shahrestan,
        verbose_name=_('Shahrestan'),
        related_name='bakhshs',
        on_delete=models.CASCADE
    )
    name = models.CharField(_('Name'), max_length=255)
    amar_code = models.IntegerField(_('Amar Code'))

    def __str__(self):
        return self.name

    class Meta:
        verbose_name = _('Bakhsh')
        verbose_name_plural = _('Bakhshs')
        ordering = ('id',)


class Shahr(models.Model):
    ostan = models.ForeignKey(
        Ostan,
        verbose_name=_('Ostan'),
        related_name='shahrs',
        on_delete=models.CASCADE
    )
    shahrestan = models.ForeignKey(
        Shahrestan,
        verbose_name=_('Shahrestan'),
        related_name='shahrs',
        on_delete=models.CASCADE
    )
    bakhsh = models.ForeignKey(
        Bakhsh,
        verbose_name=_('Bakhsh'),
        related_name='shahrs',
        on_delete=models.CASCADE
    )
    name = models.CharField(_('Name'), max_length=255)
    amar_code = models.IntegerField(_('Amar Code'))
    shahr_type = models.IntegerField(_('Shahr Type'))

    def __str__(self):
        return self.name

    class Meta:
        verbose_name = _('Shahr')
        verbose_name_plural = _('Shahrs')
        ordering = ('id',)


class Dehestan(models.Model):
    ostan = models.ForeignKey(
        Ostan,
        verbose_name=_('Ostan'),
        related_name='dehestans',
        on_delete=models.CASCADE
    )
    shahrestan = models.ForeignKey(
        Shahrestan,
        verbose_name=_('Shahrestan'),
        related_name='dehestans',
        on_delete=models.CASCADE
    )
    bakhsh = models.ForeignKey(
        Bakhsh,
        verbose_name=_('Bakhsh'),
        related_name='dehestans',
        on_delete=models.CASCADE
    )
    name = models.CharField(_('Name'), max_length=255)
    amar_code = models.IntegerField(_('Amar Code'))

    def __str__(self):
        return self.name

    class Meta:
        verbose_name = _('Dehestan')
        verbose_name_plural = _('Dehestans')
        ordering = ('id',)


class Abadi(models.Model):
    ostan = models.ForeignKey(
        Ostan,
        verbose_name=_('Ostan'),
        related_name='abadies',
        on_delete=models.CASCADE
    )
    shahrestan = models.ForeignKey(
        Shahrestan,
        verbose_name=_('Shahrestan'),
        related_name='abadies',
        on_delete=models.CASCADE
    )
    bakhsh = models.ForeignKey(
        Bakhsh,
        verbose_name=_('Bakhsh'),
        related_name='abadies',
        on_delete=models.CASCADE
    )
    dehestan = models.ForeignKey(
        Dehestan,
        verbose_name=_('Dehestan'),
        related_name='abadies',
        on_delete=models.CASCADE
    )
    name = models.CharField(_('Name'), max_length=255)
    amar_code = models.IntegerField(_('Amar Code'))
    abadi_type = models.IntegerField(_('Abadi Type'))

    def __str__(self):
        return self.name

    class Meta:
        verbose_name = _('Abadi')
        verbose_name_plural = _('Abadies')
        ordering = ('id',)



# Generated by Django 3.2.6 on 2021-08-14 21:38

from django.db import migrations
import django.db.models.deletion
import iranian_cities.fields


class Migration(migrations.Migration):

    dependencies = [
        ('iranian_cities', '0004_remove_abadi_shhahr'),
        ('test_app', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='testmodel',
            name='abadi',
            field=iranian_cities.fields.AbadiField(default=1, on_delete=django.db.models.deletion.CASCADE, to='iranian_cities.abadi'),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='testmodel',
            name='bakhsh',
            field=iranian_cities.fields.BakhshField(default=1, on_delete=django.db.models.deletion.CASCADE, to='iranian_cities.bakhsh'),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='testmodel',
            name='dehestan',
            field=iranian_cities.fields.DehestanField(default=1, on_delete=django.db.models.deletion.CASCADE, to='iranian_cities.dehestan'),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='testmodel',
            name='shahr',
            field=iranian_cities.fields.ShahrField(default=1, on_delete=django.db.models.deletion.CASCADE, to='iranian_cities.shahr'),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='testmodel',
            name='shahrestan',
            field=iranian_cities.fields.ShahrestanField(default=1, on_delete=django.db.models.deletion.CASCADE, to='iranian_cities.shahrestan'),
            preserve_default=False,
        ),
    ]



# Generated by Django 3.2.6 on 2021-08-14 21:43

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('test_app', '0002_auto_20210814_2138'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='testmodel',
            name='abadi',
        ),
        migrations.RemoveField(
            model_name='testmodel',
            name='dehestan',
        ),
        migrations.RemoveField(
            model_name='testmodel',
            name='shahr',
        ),
    ]



# Generated by Django 3.2.6 on 2021-08-14 20:50

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Bakhsh',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=255, verbose_name='Name')),
                ('amar_code', models.IntegerField(verbose_name='Amar Code')),
            ],
            options={
                'verbose_name': 'Bakhsh',
                'verbose_name_plural': 'Bakhshs',
                'ordering': ('id',),
            },
        ),
        migrations.CreateModel(
            name='Ostan',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=255, verbose_name='Name')),
                ('amar_code', models.IntegerField(verbose_name='Amar Code')),
            ],
            options={
                'verbose_name': 'Ostan',
                'verbose_name_plural': 'Ostans',
                'ordering': ('id',),
            },
        ),
        migrations.CreateModel(
            name='Shahrestan',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=255, verbose_name='Name')),
                ('amar_code', models.IntegerField(verbose_name='Amar Code')),
                ('ostan', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='shahrestans', to='iranian_cities.ostan', verbose_name='Ostan')),
            ],
            options={
                'verbose_name': 'Shahrestan',
                'verbose_name_plural': 'Shahrestans',
                'ordering': ('id',),
            },
        ),
        migrations.CreateModel(
            name='Shahr',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=255, verbose_name='Name')),
                ('amar_code', models.IntegerField(verbose_name='Amar Code')),
                ('shahr_type', models.IntegerField(verbose_name='Shahr Type')),
                ('bakhsh', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='shahrs', to='iranian_cities.bakhsh', verbose_name='Bakhsh')),
                ('ostan', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='shahrs', to='iranian_cities.ostan', verbose_name='Ostan')),
                ('shahrestan', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='shahrs', to='iranian_cities.shahrestan', verbose_name='Shahrestan')),
            ],
            options={
                'verbose_name': 'Shahr',
                'verbose_name_plural': 'Shahrs',
                'ordering': ('id',),
            },
        ),
        migrations.CreateModel(
            name='Dehestan',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=255, verbose_name='Name')),
                ('amar_code', models.IntegerField(verbose_name='Amar Code')),
                ('bakhsh', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='dehestans', to='iranian_cities.bakhsh', verbose_name='Bakhsh')),
                ('ostan', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='dehestans', to='iranian_cities.ostan', verbose_name='Ostan')),
                ('shahrestan', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='dehestans', to='iranian_cities.shahrestan', verbose_name='Shahrestan')),
                ('shhahr', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='dehestans', to='iranian_cities.shahr', verbose_name='Shahr')),
            ],
            options={
                'verbose_name': 'Dehestan',
                'verbose_name_plural': 'Dehestans',
                'ordering': ('id',),
            },
        ),
        migrations.AddField(
            model_name='bakhsh',
            name='ostan',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='bakhshs', to='iranian_cities.ostan', verbose_name='Ostan'),
        ),
        migrations.AddField(
            model_name='bakhsh',
            name='shahrestan',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='bakhshs', to='iranian_cities.shahrestan', verbose_name='Shahrestan'),
        ),
        migrations.CreateModel(
            name='Abadi',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=255, verbose_name='Name')),
                ('amar_code', models.IntegerField(verbose_name='Amar Code')),
                ('abadi_type', models.IntegerField(verbose_name='Abadi Type')),
                ('bakhsh', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='abadies', to='iranian_cities.bakhsh', verbose_name='Bakhsh')),
                ('dehestan', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='abadies', to='iranian_cities.dehestan', verbose_name='Dehestan')),
                ('ostan', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='abadies', to='iranian_cities.ostan', verbose_name='Ostan')),
                ('shahrestan', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='abadies', to='iranian_cities.shahrestan', verbose_name='Shahrestan')),
                ('shhahr', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='abadies', to='iranian_cities.shahr', verbose_name='Shahr')),
            ],
            options={
                'verbose_name': 'Abadi',
                'verbose_name_plural': 'Abadies',
                'ordering': ('id',),
            },
        ),
    ]



# Generated by Django 3.2.6 on 2021-08-14 21:34

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('iranian_cities', '0001_initial'),
    ]

    operations = [
        migrations.RenameField(
            model_name='dehestan',
            old_name='shhahr',
            new_name='shahr',
        ),
    ]



import os
import csv

from django.core.management import BaseCommand

from iranian_cities import data
from iranian_cities.models import (
    Ostan, Shahrestan, Bakhsh,
    Shahr, Dehestan, Abadi
)


class Command(BaseCommand):
    help = 'Generate all data'

    def add_arguments(self, parser):
        """initialize arguments"""
        pass

    def read_csv(self, path):
        with open(path, encoding='utf-8') as f:
            csv_reader = csv.DictReader(f)
            for row in csv_reader:
                print(row)
            return csv_reader

    def generate_ostan(self, path):
        with open(path, encoding='utf-8') as f:
            data = csv.DictReader(f)
            ostan_objs = [
                Ostan(
                    id=int(row.get('id')),
                    name=row.get('name'),
                    amar_code=row.get('amar_code')
                ) for row in data
            ]
            Ostan.objects.bulk_create(ostan_objs)
            print('Ostan Objects Created Successfully')

    def generate_shahrestan(self, path):
        with open(path, encoding='utf-8') as f:
            data = csv.DictReader(f)
            shahrestan_objs = [
                Shahrestan(
                    id=int(row.get('id')),
                    name=row.get('name'),
                    amar_code=row.get('amar_code'),
                    ostan_id=int(row.get('ostan'))
                ) for row in data
            ]
            Shahrestan.objects.bulk_create(shahrestan_objs)
            print('Shahrestan Objects Created Successfully')

    def generate_bakhsh(self, path):
        with open(path, encoding='utf-8') as f:
            data = csv.DictReader(f)
            bakhsh_objs = [
                Bakhsh(
                    id=int(row.get('id')),
                    name=row.get('name'),
                    amar_code=row.get('amar_code'),
                    ostan_id=int(row.get('ostan')),
                    shahrestan_id=int(row.get('shahrestan'))
                ) for row in data
            ]
            Bakhsh.objects.bulk_create(bakhsh_objs)
            print('Bakhsh Objects Created Successfully')

    def generate_shahr(self, path):
        with open(path, encoding='utf-8') as f:
            data = csv.DictReader(f)
            shahr_objs = [
                Shahr(
                    id=int(row.get('id')),
                    name=row.get('name'),
                    amar_code=row.get('amar_code'),
                    ostan_id=int(row.get('ostan')),
                    shahrestan_id=int(row.get('shahrestan')),
                    bakhsh_id=int(row.get('bakhsh')),
                    shahr_type=row.get('shahr_type')
                ) for row in data
            ]
            Shahr.objects.bulk_create(shahr_objs)
            print('Shahr Objects Created Successfully')

    def generate_dehestan(self, path):
        with open(path, encoding='utf-8') as f:
            data = csv.DictReader(f)
            dehestan_objs = [
                Dehestan(
                    id=int(row.get('id')),
                    name=row.get('name'),
                    amar_code=row.get('amar_code'),
                    ostan_id=int(row.get('ostan')),
                    shahrestan_id=int(row.get('shahrestan')),
                    bakhsh_id=int(row.get('bakhsh'))
                ) for row in data
            ]
            Dehestan.objects.bulk_create(dehestan_objs)
            print('Dehestan Objects Created Successfully')

    def generate_abadi(self, path):
        with open(path, encoding='utf-8') as f:
            data = csv.DictReader(f)
            abadi_objs = [
                Abadi(
                    id=int(row.get('id')),
                    name=row.get('name'),
                    amar_code=row.get('amar_code'),
                    ostan_id=int(row.get('ostan')),
                    shahrestan_id=int(row.get('shahrestan')),
                    bakhsh_id=int(row.get('bakhsh')),
                    abadi_type=row.get('abadi_type'),
                    dehestan_id=int(row.get('dehestan'))
                ) for row in data
            ]
            Abadi.objects.bulk_create(abadi_objs)
            print('Dehestan Objects Created Successfully')

    def handle(self, *args, **options):
        ostan_data_path = os.path.abspath(data.__file__).replace('__init__.py', 'ostan.csv')
        shahrestan_data_path = os.path.abspath(data.__file__).replace('__init__.py', 'shahrestan.csv')
        bakhsh_data_path = os.path.abspath(data.__file__).replace('__init__.py', 'bakhsh.csv')
        shahr_data_path = os.path.abspath(data.__file__).replace('__init__.py', 'shahr.csv')
        dehestan_data_path = os.path.abspath(data.__file__).replace('__init__.py', 'dehestan.csv')
        abadi_data_path = os.path.abspath(data.__file__).replace('__init__.py', 'abadi.csv')

        self.generate_ostan(ostan_data_path)
        self.generate_shahrestan(shahrestan_data_path)
        self.generate_bakhsh(bakhsh_data_path)
        self.generate_shahr(shahr_data_path)
        self.generate_dehestan(dehestan_data_path)
        self.generate_abadi(abadi_data_path)

        self.stdout.write(
            self.style.SUCCESS('Data generated successfully.')
        )



# Generated by Django 3.2.6 on 2021-08-14 21:07

from django.db import migrations, models
import django.db.models.deletion
import iranian_cities.fields


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('iranian_cities', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='TestModel',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('ostan', iranian_cities.fields.OstanField(on_delete=django.db.models.deletion.CASCADE, to='iranian_cities.ostan')),
            ],
        ),
    ]



# Generated by Django 3.2.6 on 2021-08-14 21:35

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('iranian_cities', '0003_remove_dehestan_shahr'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='abadi',
            name='shhahr',
        ),
    ]



from setuptools import setup, find_packages

setup(
    name='django-iranian-cities',
    packages=find_packages(exclude=['tests*']),
    package_data={'iranian_cities/data': ['*.txt']},
    include_package_data=True,
    version='1.0.0',
    description='Iranian cities support for Django',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    author='Sage Team',
    author_email='mail@sageteam.org',
    url='https://github.com/sageteam-org/django-iranian-cities',
    download_url='https://github.com/sageteam-org/django-iranian-cities/archive/refs/tags/1.0.0.tar.gz',
    keywords=['django', 'python', 'fields', 'city field'],
    install_requires=[
        'Django',
    ]
)



from django.db import models
from django import forms

from iranian_cities.models import (
    Ostan, Shahrestan, Bakhsh,
    Shahr, Dehestan, Abadi
)


class OstanField(models.ForeignKey):
    description = 'Iranian Ostan'

    def __init__(self, *args, **kwargs):
        defaults = {
            'to': Ostan,
            'on_delete': models.CASCADE
        }
        defaults.update(kwargs)
        super().__init__(*args, **defaults)

class ShahrestanField(models.ForeignKey):
    description = 'Iranian Shahrestan'

    def __init__(self, *args, **kwargs):
        defaults = {
            'to': Shahrestan,
            'on_delete': models.CASCADE
        }
        defaults.update(kwargs)
        super().__init__(*args, **defaults)

class BakhshField(models.ForeignKey):
    description = 'Iranian Bakhsh'

    def __init__(self, *args, **kwargs):
        defaults = {
            'to': Bakhsh,
            'on_delete': models.CASCADE
        }
        defaults.update(kwargs)
        super().__init__(*args, **defaults)

class ShahrField(models.ForeignKey):
    description = 'Iranian Shahr'

    def __init__(self, *args, **kwargs):
        defaults = {
            'to': Shahr,
            'on_delete': models.CASCADE
        }
        defaults.update(kwargs)
        super().__init__(*args, **defaults)

class DehestanField(models.ForeignKey):
    description = 'Iranian Dehestan'

    def __init__(self, *args, **kwargs):
        defaults = {
            'to': Dehestan,
            'on_delete': models.CASCADE
        }
        defaults.update(kwargs)
        super().__init__(*args, **defaults)

class AbadiField(models.ForeignKey):
    description = 'Iranian Abadi'

    def __init__(self, *args, **kwargs):
        defaults = {
            'to': Abadi,
            'on_delete': models.CASCADE
        }
        defaults.update(kwargs)
        super().__init__(*args, **defaults)



from django.contrib import admin
from django.contrib.admin import widgets
from iranian_cities.models import (
    Ostan, Shahrestan, Shahr,
    Bakhsh, Dehestan, Abadi
)

class IranianCitiesAdmin(admin.ModelAdmin):
    def formfield_for_foreignkey(self, db_field, request, **kwargs):
        db = kwargs.get('using')
        kwargs['widget'] = widgets.ForeignKeyRawIdWidget(
            db_field.remote_field, self.admin_site, using=db)

        if 'queryset' not in kwargs:
            queryset = self.get_field_queryset(db, db_field, request)
            if queryset is not None:
                kwargs['queryset'] = queryset

        return db_field.formfield(**kwargs)

@admin.register(Ostan)
class OstanAdmin(admin.ModelAdmin):
    list_display = ['name', 'amar_code']
    search_fields = ['name', 'amar_code']

    def has_add_permission(self, request):
        return False

    def has_delete_permission(self, request, obj=None):
        return False

    def has_change_permission(self, request, obj=None):
        return False

@admin.register(Shahrestan)
class ShahrestanAdmin(admin.ModelAdmin):
    list_display = ['name', 'amar_code', 'ostan']
    list_filter = ['ostan']
    search_fields = ['name', 'amar_code', 'ostan__name']
    raw_id_fields = ['ostan']

    def has_add_permission(self, request):
        return False

    def has_delete_permission(self, request, obj=None):
        return False

    def has_change_permission(self, request, obj=None):
        return False

@admin.register(Shahr)
class ShahrAdmin(admin.ModelAdmin):
    list_display = [
        'name', 'amar_code', 'shahr_type',
        'bakhsh', 'shahrestan', 'ostan'
    ]
    list_filter = ['ostan']
    search_fields = [
        'name', 'amar_code', 'shahr_type',
        'bakhsh__name', 'shahrestan__name', 'ostan__name'
    ]
    raw_id_fields = ['bakhsh', 'shahrestan', 'ostan']

    def has_add_permission(self, request):
        return False

    def has_delete_permission(self, request, obj=None):
        return False

    def has_change_permission(self, request, obj=None):
        return False

@admin.register(Bakhsh)
class BakhshAdmin(admin.ModelAdmin):
    list_display = ['name', 'amar_code', 'shahrestan', 'ostan']
    list_filter = ['ostan']
    search_fields = ['name', 'amar_code', 'shahrestan__name', 'ostan__name']
    raw_id_fields = ['shahrestan', 'ostan']

    def has_add_permission(self, request):
        return False

    def has_delete_permission(self, request, obj=None):
        return False

    def has_change_permission(self, request, obj=None):
        return False

@admin.register(Dehestan)
class DehestanAdmin(admin.ModelAdmin):
    list_display = ['name', 'amar_code', 'bakhsh', 'shahrestan', 'ostan']
    list_filter = ['ostan']
    search_fields = ['name', 'amar_code', 'bakhsh__name', 'shahrestan__name', 'ostan__name']
    raw_id_fields = ['bakhsh', 'shahrestan', 'ostan']

    def has_add_permission(self, request):
        return False

    def has_delete_permission(self, request, obj=None):
        return False

    def has_change_permission(self, request, obj=None):
        return False

@admin.register(Abadi)
class AbadiAdmin(admin.ModelAdmin):
    list_display = [
        'name', 'amar_code', 'abadi_type',
        'dehestan', 'bakhsh', 'shahrestan', 'ostan'
    ]
    list_filter = ['ostan']
    search_fields = [
        'name', 'amar_code', 'dehestan__name',
        'bakhsh__name', 'shahrestan__name', 'ostan__name'
    ]
    raw_id_fields = ['dehestan', 'bakhsh', 'shahrestan', 'ostan']

    def has_add_permission(self, request):
        return False

    def has_delete_permission(self, request, obj=None):
        return False

    def has_change_permission(self, request, obj=None):
        return False



from django.db import models

from iranian_cities.fields import OstanField, ShahrestanField, BakhshField, ShahrField, DehestanField, AbadiField


class TestModel(models.Model):
    ostan = OstanField()
    shahrestan = ShahrestanField()
    bakhsh = BakhshField()
    # shahr = ShahrField()
    # dehestan = DehestanField()
    # abadi = AbadiField()



# Generated by Django 3.2.6 on 2021-08-14 21:34

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('iranian_cities', '0002_rename_shhahr_dehestan_shahr'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='dehestan',
            name='shahr',
        ),
    ]
